@@ -14,6 +14,7 @@ from typing import Any
 from lionagi.operations.node import BranchOperations, Operation
 from lionagi.protocols.graph.edge import Edge
 from lionagi.protocols.graph.graph import Graph
+from lionagi.protocols.types import ID
 
 __all__ = (
     "OperationGraphBuilder",
@@ -76,6 +77,7 @@ class OperationGraphBuilder:
         node_id: str | None = None,
         depends_on: list[str] | None = None,
         inherit_context: bool = False,
+        branch=None,
         **parameters,
     ) -> str:
         """
@@ -108,6 +110,9 @@ class OperationGraphBuilder:
             # Add as metadata for easy lookup
             node.metadata["reference_id"] = node_id
 
+        if branch:
+            node.branch_id = ID.get_id(branch)
+
         # Handle dependencies
         if depends_on:
             for dep_id in depends_on:
@@ -227,6 +232,7 @@ class OperationGraphBuilder:
         source_node_ids: list[str] | None = None,
         inherit_context: bool = False,
         inherit_from_source: int = 0,
+        branch=None,
         **parameters,
     ) -> str:
         """
@@ -264,6 +270,9 @@ class OperationGraphBuilder:
         if node_id:
             node.metadata["reference_id"] = node_id
 
+        if branch:
+            node.branch_id = ID.get_id(branch)
+
         # Store context inheritance for aggregations
         if inherit_context and sources:
             node.metadata["inherit_context"] = True
