@@ -3,7 +3,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from .connections.api_calling import APICalling
-from .connections.endpoint import Endpoint
+from .connections.endpoint import Endpoint, EndpointConfig
 from .imodel import iModel
 from .manager import iModelManager
 from .rate_limited_processor import RateLimitedAPIExecutor
@@ -12,6 +12,7 @@ from .token_calculator import TokenCalculator
 __all__ = (
     "APICalling",
     "Endpoint",
+    "EndpointConfig",
     "RateLimitedAPIExecutor",
     "TokenCalculator",
     "iModel",
